@@ -12,7 +12,7 @@ class MyRefCounted : public virtual RefCounted {
 class MyRefCountedChild : public MyRefCounted {
     public:
     int val2;
-    MyRefCountedChild (int val, int val2) : val2(val2), MyRefCounted(val) { }
+    MyRefCountedChild (int val, int val2) : MyRefCounted(val), val2(val2) { }
     virtual ~MyRefCountedChild () {
         dcnt++;
     }
