@@ -10,7 +10,7 @@ public:
 class MyStaticChild : public MyStatic {
 public:
     int val2;
-    MyStaticChild (int val, int val2) : val2(val2), MyStatic(val) { }
+    MyStaticChild (int val, int val2) : MyStatic(val), val2(val2) { }
 };
 
 typedef MyStatic      PTRMyStatic;
